**Example 1: 绑定文档到房间**



Input: 

```
tccli lcic BindDocumentToRoom --cli-unfold-argument  \
    --DocumentId xx \
    --RoomId 123
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

